@@ -225,6 +225,13 @@ class CatalogServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             async def sample_create_catalog_item():
@@ -234,7 +241,7 @@ class CatalogServiceAsyncClient:
                 # Initialize request argument(s)
                 catalog_item = recommendationengine_v1beta1.CatalogItem()
                 catalog_item.id = "id_value"
-                catalog_item.category_hierarchies.categories = ['categories_value_1', 'categories_value_2']
+                catalog_item.category_hierarchies.categories = ['categories_value1', 'categories_value2']
                 catalog_item.title = "title_value"
 
                 request = recommendationengine_v1beta1.CreateCatalogItemRequest(
@@ -343,6 +350,13 @@ class CatalogServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             async def sample_get_catalog_item():
@@ -449,6 +463,13 @@ class CatalogServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             async def sample_list_catalog_items():
@@ -579,6 +600,13 @@ class CatalogServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             async def sample_update_catalog_item():
@@ -588,7 +616,7 @@ class CatalogServiceAsyncClient:
                 # Initialize request argument(s)
                 catalog_item = recommendationengine_v1beta1.CatalogItem()
                 catalog_item.id = "id_value"
-                catalog_item.category_hierarchies.categories = ['categories_value_1', 'categories_value_2']
+                catalog_item.category_hierarchies.categories = ['categories_value1', 'categories_value2']
                 catalog_item.title = "title_value"
 
                 request = recommendationengine_v1beta1.UpdateCatalogItemRequest(
@@ -709,6 +737,13 @@ class CatalogServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             async def sample_delete_catalog_item():
@@ -811,6 +846,13 @@ class CatalogServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import recommendationengine_v1beta1
 
             async def sample_import_catalog_items():
